@@ -43,18 +43,16 @@ class TestDocStringParser(unittest.TestCase):
     def test_nested_lists(self):
         html = "<ul><li>Wello</li><ul><li>Horld</li></ul></ul>"
         result = self.parse(html)
-        self.assert_contains_exact_lines_in_order(result, [
-            b'* Wello',
-            b'  * Horld'
-        ])
+        self.assert_contains_exact_lines_in_order(
+            result, [b'* Wello', b'  * Horld']
+        )
 
     def test_nested_lists_with_extra_white_space(self):
         html = "<ul> <li> Wello</li><ul> <li> Horld</li></ul></ul>"
         result = self.parse(html)
-        self.assert_contains_exact_lines_in_order(result, [
-            b'* Wello',
-            b'  * Horld'
-        ])
+        self.assert_contains_exact_lines_in_order(
+            result, [b'* Wello', b'  * Horld']
+        )
 
 
 class TestHTMLTree(unittest.TestCase):
